<?xml version="1.0"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<!-- This following section is the entry point for parsing the associated XML        -->
<!-- document. It hands out parsing to the relevent subsections and generally links  -->
<xsl:template match="/">
	<html>
		<head>
			<title>Log File Viewer</title>
			
			<style>
				h1 { font: bold 24px arial; text-decoration: underline; color: navy;	}
				h2 { font: bold 16px arial; }
				
				.header td { font: 12px verdana; }
				.header .fieldName 	{ font-weight: bold; background: #EEEEEE;}
				.header .fieldValue { }
				
				#Timers td { font: 12px verdana; }
				#Timers th { color: Black; background: #d0d0d0; vertical-align: top; border-bottom: 1px solid #c0c0c0;}
				#Timers .rowOne { padding: 0px 3px 0px 3px; font: 12px verdana; text-align: center; background-color: #E6E6E6; border-bottom: 1px solid #bbbbbb;}
				#Timers .rowTwo { padding: 0px 3px 0px 3px; font: 12px verdana; text-align: center; background-color: #E0E0E0; border-bottom: 1px solid #aaaaaa;}
				
				th { background: #DDDDDD; font: bold 12px verdana; border-bottom: 1px solid #AAAAAA;}
				.output td { font: 12px verdana; border-bottom: 1px solid #AAAAAA;}
				
				tr .levelOne 	{ background: #FA3605; border-bottom: 1px solid #D81403;}
				tr .levelTwo 	{ background: #EB7B29; border-bottom: 1px solid #C95907;}
				tr .levelThree 	{ background: #CA95FF; border-bottom: 1px solid #A873DD;}
				tr .levelFour 	{ background: #B0D5F9; border-bottom: 1px solid #90B3D7;}
				tr .default 	{ background-color: #80FF80; border-bottom: 1px solid #60DD60; }
				
			</style>
		</head>
		
		<body>
			<h1>Run-Time Log</h1>
			
			<!-- Header information -->
			<xsl:apply-templates select="DebugLog/Header"/>
			
			<!-- Timer information -->
			<xsl:apply-templates select="DebugLog/Timers"/>

			<!-- Main log entries -->
			<h2>Details of selected log entries:</h2>
			
			<table width="100%" cellspacing="1" cellpadding="0" class="output">
				<tr>
					<th width="10%">Time</th>
					<th width="65%">Message</th>
					<th width="25%">Stack Trace</th>
				</tr>
				
				<xsl:apply-templates select="DebugLog/Entry" />
			
			</table>

		</body>
	</html>

</xsl:template>



<!-- This next template match is for the log header, that is the general session     -->
<!-- information and run-time system statistics/configuration                        -->
	<xsl:template match="Header">
		
		<h2>Log file header information:</h2>
		
		<table class="header">
			<tr>
				<td class="fieldName">Output Level: </td>
				<td class="fieldValue"><xsl:value-of select="OutputLevel"/></td>
			</tr>
			
			<tr>
				<td class="fieldName">Session Started: </td>
				<td class="fieldValue"><xsl:value-of select="Time"/> :: <xsl:value-of select="Date"/></td>
			</tr>
			
			<tr>
				<td class="fieldName">Operating Environment: </td>
				<td class="fieldValue"><xsl:value-of select="Configuration/Environment"/></td>
			</tr>
			
			<tr>
				<td class="fieldName">Processor: </td>
				<td class="fieldValue"><xsl:value-of select="Configuration/Processor"/></td>
			</tr>		
			
			<tr>
				<td class="fieldName">Memory: </td>
				<td class="fieldValue">Total: <xsl:value-of select="Configuration/Memory/TotalPhysical div 1024" />Kb (<xsl:value-of select="Configuration/Memory/AvailablePhysical div 1024"/>Kb Free) - Load <xsl:value-of select="Configuration/Memory/CurrentLoad"/>% </td>
			</tr>				
			
			<tr>
				<td class="fieldName">Video Memory: </td>
				<td class="fieldValue">Total: <xsl:value-of select="Configuration/Memory/TotalVideo div 1024"/>Kb (<xsl:value-of select="Configuration/Memory/AvailableVideo div 1024"/>Kb Free)</td>
			</tr>				

			<tr>
				<td class="fieldName">Logged events: </td>
				<td class="fieldValue"><xsl:copy-of select="count(../Entry)"/></td>
			</tr>
			
			<!-- App only -->
			<tr><td colspan="2"><br /><b>--- Application -----------</b></td></tr>
			
			<tr>
				<td class="fieldName">Version:</td>
				<td class="fieldValue"><xsl:value-of select="Configuration/App/Version"/></td>
			</tr>
			
			<tr>
				<td class="fieldName">Build Mode:</td>
				<td class="fieldValue"><xsl:value-of select="Configuration/App/BuildMode"/></td>
			</tr>

		</table>
	
	</xsl:template>
	
	<xsl:template match="Timers">
		
		<h2>Timers</h2>
		
		<table id="Timers">
			<tr>
				<th style="text-align:left;">Timer name</th>
				<th>Calls</th>
				<th>Total Time</th>
				<th>Average Time</th>
			</tr>
			
			<xsl:apply-templates select="Timer"/>
			
		</table>
		
	</xsl:template>
	
	<!-- Fancy tables -->
	<xsl:template match="Timer[position() mod 2 = 0]">
		<tr>
			<td class="rowOne" style="text-align:left;"><strong><xsl:value-of select="Name" /></strong></td>
			<td class="rowOne"><xsl:value-of select="Calls" /></td>
			<td class="rowOne"><xsl:value-of select="Time" /></td>
			<td class="rowOne"><xsl:value-of select="Time div Calls" /></td>
		</tr>
	</xsl:template>

	<xsl:template match="Timer[position() mod 2 = 1]">
		<tr>
			<td class="rowTwo" style="text-align:left;"><strong><xsl:value-of select="Name" /></strong></td>
			<td class="rowTwo"><xsl:value-of select="Calls" /></td>
			<td class="rowTwo"><xsl:value-of select="Time" /></td>
			<td class="rowTwo"><xsl:value-of select="Time div Calls" /></td>
		</tr>
	</xsl:template>


<!-- This template match is for each log entry, filtered according to the selected   -->
<!-- type of event filter. For each log entry we add a row to the table.             -->
	<xsl:template match="Entry">
	
		<xsl:choose>
		
			<!-- Level 1 - URGENT -->
			<xsl:when test="@level='1'">			
				<tr>
					<td class="levelOne" align="center"><xsl:apply-templates select="Time"/></td>
					<td class="levelOne" align="left"><xsl:apply-templates select="Message"/></td>
					<td class="levelOne" align="left"><xsl:apply-templates select="CallStack" /></td>
				</tr>
			</xsl:when>
			
			<!-- Level 2 - High-ish -->
			<xsl:when test="@level='2'">			
				<tr>
					<td class="levelTwo" align="center"><xsl:apply-templates select="Time"/></td>
					<td class="levelTwo" align="left"><xsl:apply-templates select="Message"/></td>
					<td class="levelTwo" align="left"><xsl:apply-templates select="CallStack" /></td>
				</tr>
			</xsl:when>
			
			<!-- Level 3 [bin 4] - NOT URGENT -->
			<xsl:when test="@level='4'">			
				<tr>
					<td class="levelThree" align="center"><xsl:apply-templates select="Time"/></td>
					<td class="levelThree" align="left"><xsl:apply-templates select="Message"/></td>
					<td class="levelThree" align="left"><xsl:apply-templates select="CallStack" /></td>
				</tr>
			</xsl:when>			
			

			<!-- Level 4 [bin 8] - Detailed -->
			<xsl:when test="@level='8'">			
				<tr>
					<td class="levelFour" align="center"><xsl:apply-templates select="Time"/></td>
					<td class="levelFour" align="left"><xsl:apply-templates select="Message"/></td>
					<td class="levelFour" align="left"><xsl:apply-templates select="CallStack" /></td>
				</tr>
			</xsl:when>						

			<!-- No level -->
			<xsl:otherwise>
				<tr>
					<td class="default" align="center"><xsl:apply-templates select="Time"/></td>
					<td class="default" align="left"><xsl:apply-templates select="Message"/></td>
					<td class="default" align="left"><xsl:apply-templates select="CallStack" /></td>
				</tr>
			</xsl:otherwise>
			
		</xsl:choose>

			
	</xsl:template>
	
	
	<!-- Stack trace -->
	<xsl:template match="CallStack">
		<code><xsl:apply-templates select="Function" /></code>
	</xsl:template>

	<!-- Call stack function -->
	<xsl:template match="Function">
		<xsl:apply-templates/><br />
	</xsl:template>

	<!-- Log message -->
	<xsl:template match="Message">
		&#160;<xsl:apply-templates/>
	</xsl:template>



</xsl:stylesheet>